#
# spec file for package eric
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2010-2023 LISA GmbH, Bingen, Germany
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define distname eric7

# install option to install many tools as stand alone applications
%bcond_with tools

Name:           eric
Version:        24.5
Release:        1.1
Summary:        Python IDE based on Qt6
License:        GPL-3.0-or-later
Group:          Development/Tools/IDE
URL:            https://eric-ide.python-projects.org/
Source:         https://sourceforge.net/projects/eric-ide/files/%{distname}/stable/%{version}/%{distname}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-rpm-macros
BuildRequires:  python3-EditorConfig
BuildRequires:  python3-qscintilla-qt6
BuildRequires:  python3-qt6
BuildRequires:  python3-qtcharts-qt6
BuildRequires:  python3-qtwebengine-qt6
BuildRequires:  python3-xml
BuildRequires:  update-desktop-files
Requires:       python3-EditorConfig
Requires:       python3-Pygments
Requires:       python3-asttokens
Requires:       python3-black
Requires:       python3-coverage
Requires:       python3-isort
Requires:       python3-jedi
Requires:       python3-packaging
Requires:       python3-parso
Requires:       python3-qscintilla-qt6
Requires:       python3-qt6
Requires:       python3-qtcharts-qt6
Requires:       python3-qtwebengine-qt6
Requires:       python3-semver
Requires:       python3-tomlkit
Requires:       python3-trove-classifiers
Requires:       python3-xml
Requires:       qt6-sql-sqlite
Recommends:     %{name}-api = %{version}
Recommends:     python3-Markdown
Recommends:     python3-Send2Trash
Recommends:     python3-chardet
Recommends:     python3-cx_Freeze
# these are required as of install.py:doDependancyChecks
# until we provide those, just recommend them
Recommends:     python3-cyclonedx-bom
Recommends:     python3-cyclonedx-python-lib
Recommends:     python3-doc
Recommends:     python3-docutils
Recommends:     python3-pyenchant
Recommends:     python3-pylint >= 0.18.0
Recommends:     python3-pysvn >= 1.7.0
Recommends:     python3-pyyaml
Recommends:     python3-rope >= 0.9.2
Recommends:     python3-wheel
Recommends:     qt6-sql-mysql
Recommends:     qt6-sql-postgresql
Provides:       python-eric5 = %{version}
Obsoletes:      python-eric5 < %{version}
Provides:       python-eric6 = %{version}
Obsoletes:      python-eric6 < %{version}
Provides:       eric5 = %{version}
Obsoletes:      eric5 < %{version}
Provides:       eric6 = %{version}
Obsoletes:      eric6 < %{version}
BuildArch:      noarch

%description
Eric is a Python and Ruby editor and IDE, written in Python. It is
based on the Qt GUI toolkit and integrates the Scintilla editor
control.

%package api
Summary:        API files for eric6
Group:          Development/Tools/IDE
Provides:       python-eric5-api = %{version}
Obsoletes:      python-eric5-api < %{version}
Provides:       python-eric6-api = %{version}
Obsoletes:      python-eric6-api < %{version}
Provides:       eric5-api = %{version}
Obsoletes:      eric5-api < %{version}
Provides:       eric6-api = %{version}
Obsoletes:      eric6-api < %{version}

%description api
This package provides API files for eric6.
If both python-eric6 and python3-eric6 packages are installed then only one
python-eric6-api or python3-eric6-api is needed.

%prep
%setup -q -n %{distname}-%{version}

find . -name \*.py -exec sed -i -e '/^#!\/usr\/bin.*python/d' '{}' \;

%build
# nothing here

%install
%if %{with tools}
    python3 install.py -b %{_bindir} -d %{python3_sitelib} -i %{buildroot} --with-tools --no-info
%else
    python3 install.py -b %{_bindir} -d %{python3_sitelib} -i %{buildroot} --no-info
%endif
%fdupes %{buildroot}%{python3_sitelib}
ln -sf %{distname}_ide %{buildroot}%{_bindir}/%{distname}
ln -sf %{distname}_ide %{buildroot}%{_bindir}/%{name}

%files
%license eric/docs/LICENSE.txt
%doc eric/docs/README*.md eric/docs/THANKS eric/docs/changelog.md eric/docs/%{distname}-plugin.odt
%{_bindir}/*
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/%{distname}.appdata.xml
%{_datadir}/applications/%{distname}_ide.desktop
%{_datadir}/applications/%{distname}_browser.desktop
%{_datadir}/applications/%{distname}_mpy.desktop
%{_datadir}/appdata/eric7.appdata.xml
%{_datadir}/icons/eric*
%{_datadir}/icons/ericWeb.png
%{_datadir}/icons/hicolor/*/apps/eric*
%{python3_sitelib}/

%files api
%license eric/docs/LICENSE.txt
#%%dir %{_datadir}/qt6/qsci/api/
%{_datadir}/qt6/qsci/api/

%changelog
* Sat May 11 2024 jun wang <jgwang@suse.com>
- Update to version 24.5
  - changes from version 24.5
    + bug fixes
    + General
  - Changed code from using QFileSystemWatcher to our own
    implementation (EricFileSystemWatcher) based on the
    watchdog Python package in order to get more fine grained
    control over the reported changes.
    + Editor
  - Added the capability to reload the current editor via its
    context menu or the main File menu (see issue 556).
  - Added basic support for Jenkins pipeline files (and Groovy
    source files) (see issue 558).
    + Editor Outline
  - Improved the navigation capability by respecting the column
    offset when placing the cursor of the editor (see issue 554)
    + File Browser
  - Improved the navigation capability by respecting the column
    offset when placing the cursor of the editor (see issue 554)
    + Project Browser
  - Improved the navigation capability by respecting the column
    offset when placing the cursor of the editor (see issue 554)
    + Symbols Viewer
  - Completed the list of selectable code blocks.
  - changes from version 24.4
    + bug fixes
    + Code Style Checker
  - Updated these checkers
  * Security to bandit v1.7.8
  * Miscellaneous to flake8-bugbear v24.2.6
  * Logging to flake8-logging v1.5.0
    + MicroPython
  - Updated the list of known CircuitPython boards.
  - Updated the list of known UF2 capable boards.
    + pip Interface
  - Added the capability to install packages given in the
    project.dependencies section of a pyproject.toml file.
    + Project
  - Added an action to the Other Tools menu to clear the
    byte code caches of the project.
    + Shell
  - Added a context menu action to open an editor for a file
    at a line of an exception shown in the console window.
    + Snapshot
  - Disabled the snapshot functionality for Wayland based
    desktops.
    + Third Party Packages
  - Upgraded pip-licenses to version 4.3.4.
  - changes from version 24.3
    + bug fixes
    + General
  - Removed support for the deprecated eric-ide specific XML
    file formats.
  - Removed the Oxygen based icons.
  - changes from version 24.2.1
    + bug fixes
    + Code Style Checker
  - Updated these checkers to support more cases.
  * Miscellaneous
  * Security
    + Editor
  - Added an Edit menu entry tp convert tabs to spaces manually.
  - Added the capability to show local variables in the outline
    view.
  - Added code to show the indicator margin messages when the
    mouse hovers over a syntax error or warning indicator.
    + File Browser
  - Added the capability to show local variables of functions
    and methods.
    + Find In Files
  - Changed the filter entry to a filter selector with
    associated edit capability to define a list of filter
    entries.
    + Log Viewer
  - Added code to show an indicator for the log viewer icon, if
    new messages were added and the "Autoshow" option is
    deactivated.
    + MicroPython
  - Added an entry to the file manager's local and device
    context menu to rename a file.
  - Added a standalone application of the built-in MicroPython
    interface ( eric7_mpy).
  - Enhanced the MiucroPython file manager widget.
    + Plugin Repository
  - Added a label to show the number of selected entries.
    + Project Browser
  - Added the capability to show local variables of functions
    and methods.
    + Third Party packages
  - Upgraded pyflakes to version 3.2.0.
  - Upgraded jquery.js to version 3.7.1.
  - changes from version 24.2
    + bug fixes
    + Code Style Checker
  - Updated these checkers to support more cases.
  * Miscellaneous
  * Security
    + Editor
  - Added an Edit menu entry tp convert tabs to spaces manually
  - Added the capability to show local variables in the outline
    view.
  - Added code to show the indicator margin messages when the
    mouse hovers over a syntax error or warning indicator.
    + File Browser
  - Added the capability to show local variables of functions
    and methods.
    + Find In Files
  - Changed the filter entry to a filter selector with
    associated edit capability to define a list of filter
    entries.
    + Log Viewer
  - Added code to show an indicator for the log viewer icon, if
    new messages were added and the "Autoshow" option is
    deactivated.
    + MicroPython
  - Added an entry to the file manager's local and device
    context menu to rename a file.
  - Added a standalone application of the built-in MicroPython
    interface ( eric7_mpy).
  - Enhanced the MiucroPython file manager widget.
    + Plugin Repository
  - Added a label to show the number of selected entries.
    + Project Browser
  - Added the capability to show local variables of functions and methods.
    + Third Party packages
  - Upgraded pyflakes to version 3.2.0.
  - Upgraded jquery.js to version 3.7.1.
* Fri Jan 19 2024 Mikhail Terekhov <termim@gmail.com>
- Update to version 24.1
  - bug fixes
  - General
  - Changed debug logging to be directed to a debug log file `eric7_debug.txt` in
    the `.eric7` directory.
  - Code Style Checker
  - Updated these checkers to support more cases.
  - Logging
  - Miscellaneous
  - Simplify
  - Extended the documentation style checker to check the tag sequence and the use
    of deprecated tags (eric doc style).
  - Editor
  - Added the capability to comment/uncomment/toggle comment for languages
    that do not support single line comments (e.g. HTML uses `<!--` and
    `-->`.
  - Added the capability to search & replace strings containing escape codes
    (like `\n`).
  - Introduced a configurable timeout after which the quick search text occurrences
    are highlighted (if this function is activated).
  - File Browser
  - Added context menu entries to show the directory path of an item in an
    external file manager.
  - Find In Files
  - Added the capability to search & replace strings containing escape codes
    (like `\n`).
  - Multiproject
  - Added the capability to indicate externally removed projects and actions
    to clear them out.
  - Project Browser
  - Added context menu entries to show the directory path of an item in an
    external file manager.
  - Added an entry to the background context menu to show the project
    directory in an external file manager.
  - Testing
  - Extended the testing dialog to allow filtering of the result list
    based on the result status.
  - Extended the testing dialog to allow to perform a discovery run only and
    just perform selected test cases of this list.
  - Extended the testing dialog to allow to perform the test with debugger
    support (only if the dialog was started from within eric IDE).
  - Viewmanager
  - Added `Close Tabs to the Left` and `Close Tabs to the Right` context
    menu entries to the tabview view manager.
  - Added `Close Editors Above` and `Close Editors Below` context menu
    entries to the listspace view manager.
  - Virtual Environments
  - Added the capability to search for unregistered Python interpreters in
    order to create an environment entry for those selected by the user.
  - Third Party packages
  - Upgraded pip-licenses to version 4.3.3.
  - Upgraded pycodestyle to version 2.11.1.
  - Update to version 23.12
  - bug fixes
  - General
  - Improved platform support for FreeBSD.
  - Debugger
  - Added a configuration option to select whether call trace optimization
    shall be enabled (this requires no function/method definition on the
    first line of a module).
  - Improved the configuration for remote debugging (global and project
    specific).
  - Changed the Python debugger code such, that unhandled exceptions are
    reported always and handled exception only, if the specifically
    requested in the `Start Debugging` dialog.
  - Diff Dialog
  - Extended the functionality to accept two files to be diffed via the
    command line.
  - Editor
  - Changed the `Auto Save` interval to be in seconds instead of minutes.
    __Note__: The `Auto Save` interval has to be reconfigured!
  - Added the capability to save a modified file automatically when the
    editor looses the focus.
  - Added a button to format underline text of HTML documents.
  - Icons
  - Added a configuration option to override the style dependent icon size
    of the tool bars.
  - Plugin Repository Dialog
  - Introduced categories to improve the presentation of the list of available
    plugins.
  - Syntax Checker
  - Added code to show some per file and overall statistics of the check.
  - Re-introduced the JavaScript syntax checker. This time it is based on
    the `esprima` package.
- Update to version 23.11
  - bug fixes
  - General
  - Added the capability to select list entries with a configurable action
    (system default, double click, single click) (see `Interface => Interface`
    configuration page)
  - Editor
  - Enhanced the print capability with the configuration of the print
    color mode (e.g. to print an editor with a dark background).
  - Project Viewer
  - Added the context menu action "New source file..." to give a more concise
    way to create a new source file.
- Update to version 23.10
  - bug fixes
  - General
  - Made the code compatible with Python 3.12.
  - Editor
  - Added a typing completer for TOML files.
  - Enhanced the existing completers slightly.
  - Enhanced the 'Search & Replace' widget to allow a mode switching using
    a mode switch button and keyboard shortcuts (see issue 511)
  - Mercurial Interface
  - Added the capability to select the branches to be shown to the Log Browser
    window.
  - MicroPython
  - Updated the list of known CircuitPython boards.
  - pip Interface
  - Added capability to disable display of vulnerability data (e.g. if system
    does not support HTTPS protocol).
  - Shell
  - Added some more special commands (%% commands). Type `%%help` to get a dialog
    listing these commands.
  - Syntax Checker
  - Added code to the Python syntax checker to report Python Warnings.
  - Third Party packages
  - Upgraded eradicate to version 2.3.0.
  - Upgraded pip-licenses to version 4.3.2.
- Update to version 23.9
  - bug fixes
  - MicroPython
  - Added support to set the host name of the device (WiFi and Ethernet).
  - Added support to set the WiFi country code (where supported by the device
    and the installed firmware).
  - Project
  - Added capability to configure the project sources directory (e.g. if the
    project uses the 'src' directory layout schema).
  - Third Party packages
  - Upgraded pyflakes to version 3.1.0.
  - Upgraded pycodestyle to version 2.11.0.
- Update to version 23.8
  - bug fixes
  - General
  - Removed support for Python 3.7 because that is EOL.
  - Code Style Checker
  - Added these checkers to support more case.
  - use of sync functions in async functions
  - MicroPython
  - Updated the list of known CircuitPython boards.
  - Updated the list of known UF2 capable boards.
  - pip Interface
  - Added the capability to repair all dependencies with one button click.
  - Shell Window
  - Added more pages to the Shell window configuration dialog.
- Update to version 23.7
  - bug fixes
  - Code Style Checker
  - Added these checkers to support more case.
  - property decorator usage
  - PEP-604 style union type annotations
  - deprecated 'typing' symbols (PEP 585)
  - MicroPython
  - Added support for Bluetooth for RP2040 based boards (e.g. Pi Pico W).
  - pip Interface
  - Added a standalone application for Python package management with `pip`.
- Update to version 23.6
  - bug fixes
  - Code Style Checker
  - Updated these checkers to support more cases.
  - Annotations
  - Miscellaneous
  - Name Order
  - Simplify
  - Added these checkers to support more case.
  - unused arguments
  - unused global variables
  - MicroPython
  - Added support of th WebREPL device interface available on some boards with
    builtin network capability.
  - Added the capability to enable/disable the WebREPL via the WiFi menu.
  - Third Party packages
  - Upgraded pipdeptree to version 2.7.1.
  - Upgraded pip-licenses to version 4.3.1.
- Update to version 23.5
  - bug fixes
  - JavaScript Support
  - Removed JavaScript functionality depending on the `jasy` package because it
    has not been maintained for years.
  - MicroPython
  - Added support for STLink based devices.
  - Added the capability to select the device path manually in case it could not
    be detected (e.g. because the device does not have a volume name).
  - Added the capability to install the `mpy-cross` compiler from the MicroPython
    page of the configuration dialog.
  - Added a package installer for devices lacking network connectivity and the `mip`
    package manager.
  - Plugin Repository
  - Added the capability to enforce the download of plugin packages using the
    `http://` protocol (in case of missing/non-functional system `SSL` libraries).
  - Translator
  - Added support for the LibreTranslate translator (see
    https://github.com/LibreTranslate/LibreTranslate).
  - Web Browser
  - Added the capability to enforce the download of spell check dictionaries using
    the `http://` protocol (in case of missing/non-functional system `SSL` libraries).
* Wed Apr 19 2023 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 23.4.2
  - bug fixes
- Update to version 23.4.1
  - bug fixes
- Update to version 23.4
  - bug fixes
  - Editor
  - Added capability to highlight the area used by a text search (if it is not the
    whole document).
  - MicroPython
  - Updated the list of known CircuitPython boards.
  - Updated the list of known UF2 capable boards.
  - Added functionality to search for known boot volumes in the UF2 flash dialog.
  - Added functionality to install packages using `mip` or `upip`.
  - Added support for WiFi enabled boards.
  - Added support for Bluetooth enabled boards.
  - Added support for Ethernet enabled boards.
  - Added support for synchronizing the board time via NTP for network enabled
    boards.
  - Added a dialog to enter the parameters to convert a .hex or .bin firmware
    file to UF2.
  - Mini Editor
  - Added capability to highlight the area used by a text search (if it is not the
    whole document).
  - Syntax Checker
  - Added the capability to define names to be treated as builtin names by the
    `pyflakes` checker globally (see configuration dialog `Editor => Code Checkers`
    page and on a per project basis (see `Project-Tools => Check => Syntax`).
  - Third Party packages
  - Upgraded eradicate to version 2.2.0.
  - Upgraded pipdeptree to version 2.5.2.
  - Upgraded pip-licenses to version 4.1.0.
- Update to version 23.3
  - bug fixes
  - MicroPython
  - Updated the list of known CircuitPython boards.
  - Updated the list of known UF2 capable boards.
  - Some smaller enhancements for CircuitPython devices.
  - Added functionality to update modules of CircuitPython devices with `circup`
    (adapted for use within eric-ide).
  - Added functionality to show the installed firmware version and the version
    available on Github (for all boards except 'Calliope mini').
  - Added support for Teensy 4.0 and 4.1 devices with MicroPython.
  - Extended the file manager to be able to load device files into an editor and
    save them back to the device.
  - PDF Viewer
  - Added a tool based on `QtPdf` and `QtPdfWidgets` to show the contents of PDF
    files.
- Update to version 23.2
  - bug fixes
  - Human Machine Interfaces
  - Changed code to use the default tab bar icon size.
  - Debug Client - Python
  - Removed the internal copy of the 'coverage' package and made it a dependency.
  - pip Interface
  - Added code to show the full text of security advisories in the package details
    dialog.
  - Added a tab to show the defined project URLs to the package details dialog.
  - Changed the package details dialog to show just those tabs, that contain some
    data.
  - Help Viewer
  - Added a configuration option to disable the search for new QtHelp documents
    on startup.
  - Web Browser
  - Updated the included 'jquery.js' and 'jquery-ui.js' needed by the Speeddial page
    and adapted this page to the new/changed functions.
- Update to version 23.1.1
  - bug fixes
- Update to version 23.1
  - bug fixes
  - Class Browsers
  - Removed the IDL and Protobuf class browsers to include them in their respective
    plugin.
  - Code Formatting
  - Added an option to configure the 'known first party' packages to the isort
    configuration dialog.
  - Editor
  - Changed the handling of files whose type cannot be determined by the Python
    mimetypes module to check against a list of known text file patterns and
    ultimately asking the user, if the file in question is a text file (see
    `Mimetypes` configuration page).
  - Added a configuration option to disable the source navigator (selector boxes above
    the editor or code outline right of the editor). This is useful e.g. on very small
    screens.
  - Added support for multiple cursor paste.
  - Find In Files
  - Added context menu entries in Replace mode to select/deselect all entries
    (e.g. useful for checking big replacement lists for validity).
  - MicroPython
  - Updated the list of known CircuitPython boards.
  - Updated the list of known UF2 capable boards.
  - Project
  - Extended the list of default file type associations.
  - Added the capability to edit the file type associations from within the
    project properties dialog.
  - Project Viewer
  - Removed the CORBA and Protobuf viewers to make them available as plugins.
  - Added a `Collapse all files` entry to the Project Sources viewer.
  - Version Control Systems - git
  - Changed git interface code to work with `git worktrees`.
  - Added a dialog to manage worktrees ( `git worktree` commands).
  - Third Party packages
  - Upgraded pipdeptree to version 2.3.3.
  - Upgraded pip-licenses to version 4.0.2.
  - Upgraded pycodestyle to version 2.10.0.
  - Upgraded pyflakes to version 3.0.1.
- Update to version 22.12
  - bug fixes
  - Code Formatting
  - added an interface to resort the import statements of Python source files with
    the 'isort' utility
  - Code Style Checker
  - added a few imports style options and added a sorting function iaw. the 'isort'
    utility
  - CycloneDX Interface
  - addad capability to generate readable (prettified) output
  - Debugger
  - increased the configuration possibilities for the network interface the debug
    server listens on
  - added the capability to configure the debug server of the IDE to listen at a
    fixed network port (default 35000)
  - added a stack frame selector to the global variables viewer (synchronized with
    the one of the local variables viewer)
  - MicroPython
  - introduced a configuration option to enable manual selection of devices
    (e.g. for unknown devices or inside the Linux container of ChromeOS)
  - Previewers
  - added a button to copy the contents of the HTML previewer to the clipboard
  - Project
  - added capability to reload the current project
  - Qt Tools
  - added a configuration option for the path of the 'qhelpgenerator' tool
    (it is installed differently by various Linux distributions)
  - Web Browser
  - added bookmark importer entries for
  - Falkon
  - Microsoft Edge
  - Opera (Chromium based)
  - Vivaldi
- Update to version 22.11.1
  - bug fixes
- Update to version 22.11
  - bug fixes
  - Debugger
  - added the capability to apply the current selection of the `Variable Types Filter`
    to see its effect
  - added the capability to add a positive (`Show Only`) or negative (`Don't Show`)
    variables filter to the global and local variables viewers
  - Editor
  - added a configuration option to reject the loading of a file that exceeds the
    configured size
  - opening a file that is not a text file will be rejected
  - Git Interface
  - added support for `git blame --ignore-revs-file` including an action to create
    such a skip list file
  - Mercurial Interface
  - added support for `hg annotate --skip` including an action to create a file
    for the commit IDs to be skipped (one per line)
  - Project
  - refined the embedded environment handling
  - added a topic to the project properties to define the sources start path within
    the project ('Translations Properties Dialog')
  - Scripts
  - renamed 'eric7.py' to 'eric7_ide.py' in order to remove the ambiguity between the
    main script and the package
  - Styles and Themes
  - added a style sheet for the dark gray theme
  - Translator
  - added the command line switch `--no-multimedia` to forcefully disable the
    pronounce function of the translator widget (in case Qt aborts the application
    start process)
  - Various
  - changed the Gmail interface to use the Google API packages for authentication
    (OAuth2) and sending of emails
  - Virtual Environments
  - added the capability to enter a descriptive text for a virtual environment
  - Third Party packages
  - upgraded coverage to version 6.5.0
  - upgraded pycodestyle to version 2.9.1
  - upgraded pyflakes to version 2.5.0
- Update to version 22.10
  - bug fixes
  - API files
  - added API files for the Adafruit CircuitPython Library Bundle
  - updated the CircuitPython API file
  - Code Formatting
  - added a Project menu entry to just configure the formatting parameters
  - added the capability to format the source code after a diff or check
    run from within the results dialog
  - Code Style Checker
  - added some more security related checks
  - extended the list of miscellaneous checks
  - pip Interface
  - changed the pip licenses dialog to show the count of each individual license
  - Project
  - added capability to use a virtual Python environment named `.venv` embedded
    within the project directory
  - added a configuration option to save the project automatically whenever it changes
  - Testing
  - extended the testing dialog to allow test case filtering on markers (pytest only)
  - extended the testing dialog to allow test case filtering by a list of test name
    patterns (unittest) or test name expression (pytest)
  - Translator
  - added support for 'Ukrainian' to the DeepL translator interface
  - install scripts
  - modified install.py script to differentiate between optional and required
    dependencies
  - modified the install script such, that the qt6-applications package is only
    installed upon request (--with-tools)
  - extended the install-dependencies.py script to differentiate between optional and
    required dependencies. Invoke it with
    `python3 install-dependencies.py --all | --optional | --required`.
- Update to version 22.9
  - bug fixes
  - Code Style Checker
  - extended the Naming style checker to be more PEP8 compliant
  - updated imports checker to support banned module patterns
  - updated the annotations checker to support more cases
  - updated the simplifications checker to support more cases
  - Debugger
  - added capability to suppress reporting of unhandled exceptions
  - Editor
  - extended the Pygments based lexer to support the various comment variants
  - Interface
  - added capability to expand or shrink the sidebar by clicking on the empty
    part of the icon bar
  - MicroPython
  - added capability to connect to devices for which only the serial port name
    is available
- Update to version 22.8
  - bug fixes
  - API Generator
  - added capability to configure a start directory for the API generation
    process
  - Code Documentation Generator
  - added capability to configure a start directory for the documentation
    generation process
  - Code Formatting
  - added an interface to reformat Python source code with the 'Black' utility
  - Eric Widgets
  - extended EricPathPicker to offer a pathlib.Path based interface
  - extended EricFileDialog to offer a pathlib.Path based interface
  - extended the EricFileDialog Wizard to create the pathlib.Path based methods
  - MicroPython
  - updated the list of known CircuitPython boards
  - updated the list of known UF2 capable boards
  - pip Interface
  - included a copy of pipdeptree and patched it to work with Python 3.11+
  - added capability to repair dependency issues
  - added capability to generate text for a 'constraints.txt' file
  - setup Wizard
  - added support for `project_urls`
  - added support for `entry_points`
  - added a variant to create a `setup.cfg` file
  - added a variant to create a `pyproject.toml` file
  - Third Party packages
  - upgraded coverage to version 6.4.2
  - upgraded eradicate to version 2.1.0
- Update to version 22.7
  - bug fixes
  - Code Style Checker
  - introduced an additional documentation style type for eric and blacked
    code (i.e. code formatted by the 'Black' tool)
  - CycloneDX Interface
  - added capability to create a Software Bill of Materials (SBOM) file in
    CycloneDX format
  - pip Interface
  - added SBOM capability
  - Project
  - added SBOM capability
  - added License to project properties
  - Styles and Themes
  - added a style and theme with a dark gray background
  - Translator
  - changed DeepL support to the v2 API and added support for the Free API
    next to the Pro API
  - removed the interface to Glosbe as they don't provide an API anymore
  - removed the interface to PROMT as they don't provide a free API anymore
  - upgraded the interfaces to the Google V2 and Microsoft translators
  - Virtual Environments
  - added the capability to upgrade a virtual environment
- Update to version 22.6
  - bug fixes
  - Dataview Coverage
  - added support to write coverage reports as HTML, JSON or LCOV files
  - removed the support for writing annotated sources
    (deprecated in coverage.py)
  - Mercurial Interface
  - added configuration option to override the automatic search for the hg
    executable
  - MicroPython
  - updated the list of known CircuitPython boards
  - updated the list of known UF2 capable boards
  - pip Interface
  - added a filter to the package licenses dialog
  - Syntax Checker
  - changed the TOML syntax checker to use 'tomlkit' because 'toml' is no
    longer maintained
  - Testing
  - reworked the former unittest interface to allow to support testing
    frameworks other than "unittest"
  - implemented support for the "unittest" and "pytest" frameworks
  - Wizards
  - extended the QInputDialog wizard to support the `getMultiLineText()`
    function
  - Third Party packages
  - upgraded pip-licenses to version 3.5.4
  - upgraded coverage to version 6.4.0
- Update to version 22.5
  - bug fixes
  - General
  - added configuration options to disable the embedded `Find/Replace In
    Files` and `Find File` tools and use dialog based variants instead
  - Mercurial Interface
  - added capability to enter a revset expression when defining a revision
    to operate on
  - pip Interface
  - added the capability to save the licenses overview as a CSV file
- Update to version 22.4
  - bug fixes
  - General
  - added capability to upgrade PyQt packages eric depends on from within eric
  - added capability to upgrade eric from within eric
  - pip Interface
  - added a vulnerability check for installed packages based on "Safety DB"
  - added a widget to show a package dependency tree
  - added a button to search for more packages (i.e. one more page of results)
  - Third Party packages
  - upgraded coverage to version 6.3.2
  - upgraded mccabe to version 0.7.0
- Adjust dependencies and installation items
* Sat Mar  5 2022 Hans-Peter Jansen <hpj@urpla.net>
- Add new EditorConfig dependency
- Add qt6-sql-sqlite dependency and recommends for mysql and
  postgresql plug-ins
* Sat Mar  5 2022 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 22.3
  - bug fixes
  - General
  - - performance improvements
  - - added a '__main__.py' script to allow starting eric7 with
    'python3 -m eric7'
  - MicroPython
  - - enhanced support for ESP32 devices
  - - updated the list of known UF2 capable boards
* Thu Mar  3 2022 Hans-Peter Jansen <hpj@urpla.net>
- Switched to PyQt6 based eric7
- Update to version 22.2
  - bug fixes
  - General
  - - dropped support for Python 3.6 because that is end-of-life
  - File Browser
  - - added capability to open SVG files in the text editor
  - Help Viewer
  - - added bookmarks to the internal help viewer
  - MicroPython
  - - updated the list of known CircuitPython boards
  - - updated the list of known UF2 capable boards
  - - added support for ESP32-C3, ESP32-S2 and ESP32-S3 chips
  - - added a dialog to show information for a connected board
  - Project Browser
  - - added capability to open SVG files in the text editor to the
    Project
    Others Browser
  - Styles and Themes
  - - added a dark blueish style (QSS and Highlighters) and an
    associated theme
    (dark_blue.ethj and dark_blue_with_stylesheet.ethj)
  - Third Party packages
  - - upgraded coverage to 6.2.0
- Update to version 22.1.1
  - bug fix
- Update to version 22.1
  - bug fixes
  - Code Style Checker
  - - added a checker for various import statement topics
  - Color Themes
  - - added capability to import and export ALL colors
  - Mini Editor
  - - added configuration capability
  - QSS Previewer
  - - added disabled widgets in order to show their colors as well
  - Styles and Themes
  - - added a dark greenish style (QSS and Highlighters) and an
    associated theme
    (dark_green.ethj and dark_green_with_stylesheet.ethj)
- Update to version 21.12
  - bug fixes
  - first release of eric7 (i.e. the PyQt6 port of eric6)
  - General
  - - rearranged the interface and modernized the sidebars layout
  - - integrated some dialogs into the sidebars
  - Debugger
  - - added code to remember the list of recently used breakpoint
    conditions
    in the editor and the breakpoint viewer
  - - added code to enter the script to be run/debugged/... in the
    start dialog
  - Editor
  - - added the capability to suppress syntax highlighting by
    associating
    the file type 'Text'
  - - added code to move a breakpoint to a line actually creating
    some byte code
    (Python only)
  - - added mouse button capability to perform undo/redo actions
    (Extra
    Buttons 1 and 2)
  - - added support for 'multi cursor editing' (additional cursors
    with
    Meta+Alt+Left Click, Esc to end it)
  - Find In Files
  - - integrated the dialog into the right sidebar
  - Help Viewer
  - - added an internal help viewer based on QTextBrowser or
    QWebEngine
  - Jedi
  - - integrated the Assistant Jedi plugin as a fixed part of eric
  - - added code to jump to references when clicked on a
    definition
  - - added support for mouse hover help
  - - added support for simple refactorings to the editor context
    menu
  - Plugin Repository
  - - added an integrated plugin repository viewer (right side)
  - Plugin Uninstall Dialog
  - - added capability to uninstall several plugins with one
    invocation of the
    dialog
  - Project
  - - added a 'Start' context sub menu to the project sources
    browser
  - Shell
  - - added capability to save the contents of the shell window
    into a file
  - Unit Test
  - - added capability to remember the most recently used test
    data
  - Viewmanager
  - - added a 'Start' sub menu to the tabview and listspace view
    managers
    context menu
  - Virtual Environments
  - - integrated the Virtual Environments Manager window into the
    right side bar
  - - added a standalone variant of the Virtual Environments
    Manager
  - Third Party packages
  - - upgraded coverage to 6.1.2
  - - upgraded pycodestyle to version 2.8.0
  - - upgraded mccabe to version 0.6.1
  - - upgraded pyflakes to version 2.4.0
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 21.11
  eric 21.11 has been released. It fixes just a few bugs. This will be the last
  release of the 'eric6' line of development (i.e. the one requiring PyQt5/Qt5 as
  its execution environment).
* Mon Oct 25 2021 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 21.9
  - bug fixes
  - MicroPython
  - - extended the list of known CircuitPython and UF2 capable
    devices
  - Unit Test
  - - added support for sub-tests
- Update to version 21.7
  - bug fixes
- Update to version 21.6
  - bug fixes
  - Tasks
  - - made the task properties dialog adapt to the task kind
  - - added code to get typed manual tasks
  - UML Diagrams
  - - extended the class items to show class attributes
  - - added code to load a saved UML diagram via the file browser
    or
    the project others browser
  - - improved the diagram layout of the Import Diagram and the
    Application Diagram
  - - added code to save and load diagrams as JSON files
  - - changed code to print diagrams
- Update to version 21.5
  - bug fixes
  - Code Style Checker
  - - added a checker to find code that could be simplified
  - - added capability to the results page to filter the messages
    based on
    message code
  - - improved the statistics handling
  - - updated pycodestyle to version 2.7.0
  - MicroPython
  - - added option to select the baud rate for flashing ESP32 and
    ESP8266 boards
  - - updated the BBC micro:bit API file to support micro:bit V2
  - Python Lexer
  - - updated the substyle contents
  - Syntax Checker
  - - updated pyflakes to version 2.3.1
  - Third Party packages
  - - removed most of the bundled Third Party packages in favour
    of pip
    installed packages
- Update to version 21.4
  - bug fixes
  - Code Style Checker
  - - added a checker to help porting to the 'pathlib' module
  - Debugger
  - - extended the Start... dialogs to allow to override some
    global
    configuration settings (redirect stdin/stdout/stderr)
  - Editor
  - - added capability to delete the matching brace if the cursor
    is
    in between them (e.g. {}) and backspace is pressed
  - Pip Interface
  - - added support for a re-installation of selected packages
  - Shell
  - - changed the shell special commands to start with a '%%' (e.g.
    %%start)
- Update to version 21.3
  - bug fixes
  - General
  - - changed the default file format for several generated files
    to be based on
    JSON
  - - added support for Cython
  - Debugger
  - - added capability to delete environment variables for the
    debugged script
    by adding a '-' to the variable name in the start dialog
  - Debug Viewer
  - - changed code to show project relative paths in the
    breakpoint viewer
  - Editor
  - - integrated the "Quick Search" functionality into the editor
    search widget
  - - added support for Cython to the code outline/navigation
    lists
  - - added support for Cython to the Typing Completers
  - File Browser
  - - added capability to show/hide hidden files (i.e. those
    starting with '.')
  - - added capability to create new files/directories and delete
    them
  - - added Cython support to show the file structure of these
    files
  - Mercurial Interface
  - - added support for Mercurial 5.7
  - MicroPython
  - - added support for "Raspberry Pi Pico" (i.e. RP2040 based
    boards)
  - - extended the list of supported (recognized) CircuitPython
    boards
  - - added capability to manually configure devices not yet known
    by eric6
  - - added a generic dialog for flashing UF2 capable devices
    (with device
    detection)
  - - added code to support 'middle button paste'
  - pip Interface
  - - changed code for the search function to work with the PyPI
    search page
    because the XML-RPC search interface of PyPI is still disabled
  - - extended the Package Details dialog to include buttons to
    install,
    upgrade or uninstall the package
- Update to version 21.2
  - bug fixes
  - General
  - - added support for PyQt6
  - - added support for PySide6
  - Code Style Checker
  - - added a commented code whitelist patterns to the
    Miscellaneous Checker
  - - added support for the '@yield' and '@ytype' tags
  - Debugger
  - - added support for debugging multiprocess scripts using these
    methods
  - -- QProcess.start(), QProcess.startDetached()
  - -- subprocess.Popen()
  - -- multiprocessing.Process()
  - -- os.spawnl...(), os.spawnv...(), os.posix_spawn...(),
    os.fork(),
    os.fork_exec()
  - -- _winapi.CreateProcess(), _subprocess.CreateProcess()
  - - added support for debugging code strings (-c, --code) or
    script modules
    (-m, --module)
  - - added support for the "Continue Until" action execution code
    until the
    current cursor line (if it is greater than the current line) or
    until
    returning from the current frame
  - Documentation Generator
  - - added support for the '@yield' and '@ytype' tags to document
    generators
  - Editor
  - - added code to enclose the current selection by entering ", '
    or a bracket
    ( (, ), [, ], {, }, <, > ) characters
  - - extended the exporters to support sub-styles
  - - added functionality to insert docstring templates via the
    context menu
    (cursor placed on first line of function definition), after
    entering
    the docstring start string (e.g. """ for Python) or via a
    keyboard
    shortcut (default: Ctrl+Alt+D) when cursor is either placed on
    the
    function definition line or after the end of the function
    definition
  - Find File Dialog
  - - added option to exclude hidden files and directories
  - - changed directory tree search logic to derive the file
    patterns from the
    project file type associations, if the directory to be searched
    is a
    sub-directory of the project
  - User Interface
  - - added capability to show Qt6 documentation (configurable)
  - VirtualEnv Manager
  - - improved the handling of virtual environments slightly
  - Web-Browser
  - - added an error page for not supported eric: URLs
  - Third Party packages
  - - updated eradicate.py to 2.0.0
  - - updated chardet to 4.0.0
  - - updated coverage.py to 5.3.1
  - - updated editorconfig to 0.12.3
  - - updated Pygments to 2.7.4
* Sat Jan  2 2021 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 21.1
  - bug fixes
- Update to version 20.12.1
  - bug fixes
- Update to version 20.12
  - bug fixes
- Update to version 20.11
  - bug fixes
  - Editor
  - - added support for TOML files
  - Main Window
  - - added a dialog showing information about the installation
    process
    (see Help menu)
  - Mini Editor
  - - added a status bar languages menu
  - - added a status bar zoom slider
  - - added zoom actions menu and toolbar
  - Syntax Checker
  - - added a syntax checker for TOML files
  - Web Browser
  - - added a SSL information page to the site info dialog
  - - added a clickable SSL info label to the URL entry
  - Various
  - - changed code to not use deprecated 'QRegExp' anymore
- Don't attempt to install/use pyqt5-tools/qt5-applications
- Don't create install info file
  rpmlint complains that this file contains buildroot
* Mon Oct  5 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 20.10
  - bug fixes
  - Editor
  - - added an outline widget showing the structure of the editor
    source code and allowing to navigate in the code
  - Python Disassembly Viewer
  - - added a tool to visualize the Python byte code generated
    from a Python source file
  - - added a viewer to visualize Python byte code generated from
    a Python traceback of an exception as an additional tab of
    the debug viewer
  - - added capability to show information about a code object
  - Third Party packages
  - - updated Pygments to 2.7.0
  - - updated coverage.py to 5.3.0
  - - removed th no longer needed 'enum' package
  - Various
  - - changed the code to not rely on the Qt Resource system
    anymore (no .qrc files and no use of pyrcc5 anymore)
- Update to version 20.9
  - bug fixes
  - File Browser
  - - changed it to react upon changed files if their contents is
    shown Tasks
  - - added separate task categories for 'Test' and
    'Documentation' tasks
  - Mercurial Interface
  - - removed the interface for the deprecated 'fetch' extension
  - VCS Interfaces
  - - added a configuration option to disable the VCS toolbars
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 20.8
  - bug fixes
  - removed support for Python2
  - removed support for Qt4 (PyQt4 and pyside)
  - - added menu action for pip cache management
  - - changed the dialog to allow the selection of checker categories
  - - added several security related checks (ported from bandit)
  - - extended the dialog to show a list of files still to be checked
  - - updated pycodestyle to version 2.6.0
  - - updated pyflakes to version 2.2.0
  - - updated asttoken to version 2.0.4
  - bug fixes
  - - added a configurable URL entry color to indicate sites with certificate
    issues
  - - added code to ask for the title of a new bookmark folder
  - - updated Pygments to 2.3.1
* Sat May  9 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 20.5:
  - MicroPython
  - - added support for Calliope mini
  - Third Party packages
  - - updated Pygments to 2.3.1
* Sun Apr  5 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 20.4:
  - bug fixes
  - General
  - - included a new icon set based on the Breeze icons of KDE
* Sat Mar 14 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 20.3:
  - bug fixes
  - Debugger
  - - added debugging support for QRunable
  - Mercurial Interface
  - - added support for the '--secure' flag of hg import as of
    Mercurial 5.3
  - Syntax Checker
  - - updated pyflakes to repository as of 2020-02-03
  - Third Party packages
  - - updated coverage.py to 5.0.3
* Mon Feb  3 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 20.2:
  - bug fixes
  - remove source URL workaround (fixed upstream)
* Sun Jan 26 2020 Hans-Peter Jansen <hpj@urpla.net>
- fix source URL
* Sun Jan 26 2020 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 20.1:
  - bug fixes
  - MicroPython
  - - added entries to the ESP menu to show the Chip ID, Flash ID and
    MAC Address
  - - added entries to the ESP menu to backup and restore a firmware
  - Web Browser
  - - added support for viewing PDF documents inside the web browser
    (requires PyQt/Qt 5.13 or better)
* Sun Dec  8 2019 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 19.12
  - bug fixes
  - MicroPython
  - added a menu entry to show the local and device time side-by-side
  - added a PyBoard menu entry to flash a new firmware
  - added a menu entry to open the firmware download page of a device
  - Syntax Checker
  - added a syntax checker for JSON files
  - added a syntax checker for YAML files
  - install script
  - added the "--yes" flag to allow installation of all missing
    prerequisites with pip without asking
- removed the patches
  * eric-focus-issues-fix.patch
  * eric-more-fixes.patch
* Thu Dec  5 2019 Hans-Peter Jansen <hpj@urpla.net>
- add another patch to fix more issues
  * eric-more-fixes.patch
* Sun Dec  1 2019 Hans-Peter Jansen <hpj@urpla.net>
- add patch to fix two focus related issues
  * eric-focus-issues-fix.patch
* Thu Nov 28 2019 Hans-Peter Jansen <hpj@urpla.net>
- Add python-Markdown recommendation (for *.md files preview)
- Fix a small glitch with sed
* Wed Nov 13 2019 Hans-Peter Jansen <hpj@urpla.net>
- Fix source path
* Tue Nov 12 2019 Hans-Peter Jansen <hpj@urpla.net>
- Clean up spec file
* Tue Nov  5 2019 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 19.11
  - bug fixes
  - Editor
  - extended the spell checking functionality for all text files
  - added a context menu to select spell check language
  - made the preview refresh timeout configurable
    (see Editor -> File Handling config page)
  - Error Message Dialog:
  - added a configurable minimum severity for messages being
    shown in a dialog (see Application config page)
  - MicroPython
  - added support for PyBoard
  - Previewers
  - enhanced the Markdown previewer by using the PyMdown
    extensions, if they are available and have been enabled
  - enhanced the Markdown previewer to support MathJax, if it
    has been enabled
  - enhanced the Markdown previewer to support Mermaid via the
    md_mermaid extension, if it is available and has been enabled
- Update to version 19.10
  - bug fixes
  - removed runtime support for Python2 and PyQt4
  - changed minimum Qt/PyQt version required to 5.9.0
  - Code Style Checker
  - added more comprehension checks
  - added checks for insecure use of sys.version and
    sys.version_info
  - added a checker class for type annotations
  - Editor
  - added configuration option to set the tab and indentation
    width for each languages separately (as an override to the global
    ones)
  - added a typing aid for YAML
  - QFileDialog Wizard:
  - added support for the QFileDialog.get...Url() methods
  - added support for E5FileDialog
  - Third Party packages
  - updated coverage.py to 4.5.4
- Remove PyQt4 support from spec
- Enable dependency checks
* Mon Sep  9 2019 Hans-Peter Jansen <hpj@urpla.net>
- fix URL
* Sat Sep  7 2019 Hans-Peter Jansen <hpj@urpla.net>
- Update to version 19.9
  + bug fixes
  + added widgets to support development for embedded controllers
    with MicroPython (ESP8266/ESP32, CircuitPython and BBC micro:bit)
  + Main Window
    + added an action to the Windows menu to activate the current
    editor
  + Mercurial Interface
    + added an action to commit a merge
  + Web Browser (NG)
    + added support for the QWebEnginePage.Notifications as Qt 5.13.0
  + API Files
    + added API files for BBC micro:bit MicroPython and updated
    the PyQt5 API files
  + API Generator
    + added the -i switch to ignore the existence of builtin modules
    when creating API files
- Update to version 19.8
  + bug fixes
  + Third Party packages
    + upgraded pyflakes to version 2.1.1 plus repository changes
    to fix some issues (until 2019-07-09)
- Update to version 19.7
  + bug fixes
  + Code Style Checker
    + added check for commented code that should be removed
    + added check for line continuation methods not suggested by PEP-8
    + added checks for naive uses of datetime classes
- Update to version 19.6
  + bug fixes
  + Code Style Checker
    + added checks for use of 'gettattr' and 'setattr', base super()
    calls and 'assert False' statements
  + Editor
    + Python Typing
    + added support for 'from ... import (...)'
    + changed the indentation when the previous line ends with
    '(', '[' or '{'
    + Ruby Typing
    + changed the indentation when the previous line ends with
    '(', '[' or '{'
  + Mercurial Interface
    + extended the log browser to start with showing all incoming
    and the first batch of local changesets
    + show different icons for incoming, outgoing and normal
    changesets
    + added capability to search and filter based on the changeset
    phase
    + added support for the 'closehead' extension (as of Mercurial
    4.8)
    + added support for the '--keep' flag of the shelve command
    (as of Mercurial 5.0)
  + Shell
    + added capability to place the Shell window in the left or
    right side container
  + setup.py Wizard
    + updated the Trove classifiers list
    + added capability to retrieve the Trove classifiers list from
    PyPI
  + Variables Viewer
    + reimplemented Variables Viewer using QTreeView with
    unlimited access to big arrays, dicts, etc. because elements
    are lazy loaded
    + highlighting of still unloaded (default: yellow background)
    and last
  + changed variable(s) (default: green background)
    + colors for highlighting are configurable through
    Debugger->General
    + expand / collapse variables with children on double click on
    first column,
  + in all other cases display detail window
    + handling of dict views improved (can be expanded like lists)
    + show tooltips on all elements which don't fit into current
    column width
    + new options in the context menu, e.g. expand / collapse all
    child nodes
  + Third Party packages
    + updated EditorConfig to 0.12.2
- Update to version 19.5
  + bug fixes
  + General
    + added functionality to provide eric6 via PyPI. Installation
    can be accomplished via 'pip install eric-ide'
  + Python AST Viewer
    + added a tool to visualize the AST for a Python source file
  + Snapshot Tool
    + added code to support screenshots on Wayland desktops (KDE
    and Gnome)
- Deal with relocated docs
* Sun Apr  7 2019 seanlew@opensuse.org
- Update to 19.04
  * added a checker for advised forms of the return statement
  * addd extended regex support for C++ 11
  * added capability to configure the subline indent
  * added capability to frame the line containing the cursor
  * added support for sub-styling
  * extended support for keyword sets
* Sun Mar  3 2019 seanlew@opensuse.org
- Update to 19.03
  * added an interface for the conda environment/pkg management
  * suppress auto-completions in various circumstances
  * changed the if from menu based -> widget-based in toolbox
  * extended the environment def by a flag indicting remote access
  * updated pycodestyle to 2.5.0
  * updated pyflakes to 2.1.0
* Mon Feb 18 2019 seanlew@opensuse.org
- Update to 19.02
  * added capability to suppress some markers in the marker map
  * add capability to the multi project browser to remove a project
  * added support to select a client SSL Cert (Qt 5.12)
* Fri Jan 11 2019 seanlew@opensuse.org
- Update to 19.01
  * added entry to select the virt environment of the current proj
  * added support for some resource compiler options
  * added single application mode
  * change logic inside eric to use a browser to show help text
* Sat Dec 29 2018 sean@suspend.net
- Update to 18.12:
  * changed the 'regexp' search option to use POSIX mode
  * added the ability to search for a regex
  * added support for the resource-suffix and --import-from= opts
  * added a button to open the translator config page
  * extended the env definition by a flag indicating an Anaconda env
  * changed the start menu to give a list of defined envs
* Fri Nov  2 2018 sean@suspend.net
- Update to 18.11:
  - IRC
  - -  added support for some of the "/" commands to the user context menu
  - Translator
  - - changed DeepL support to DeepL Pro
  - VCS
  - - added capability to show some VCS information in the main status window
* Tue Oct 23 2018 Hans-Peter Jansen <hpj@urpla.net>
- Update to 18.10:
  - General
  - - changed the extension of the generated script files for Windows
    from '.bat' to '.cmd'
  - Debugger
  - - added code to use the default virtual environment, if none has
    been configured yet
  - IRC
  - - added support for the /query, /notice, /ping, /ignore, /unignore,
    /away, /join, /part and /partall commands
  - Tasks
  - - added code to mark a line as not containing a task with '__NO-TASK__'
* Wed Sep 12 2018 Hans-Peter Jansen <hpj@urpla.net>
- Update to 18.09:
  - bug fixes
  - Mercurial Interface
  - - added support for Mercurial 4.7 extended commands 'graft', 'rebase' and
    'export'
* Fri Aug  3 2018 hpj@urpla.net
- Update to 18.08:
  - bug fixes
  - General
  - - made the activation of these internal tools configurable
  * Template-Viewer
  * File-Browser
  * Symbols
  * Code Documentation Viewer
  * Cooperation
  * IRC
  * Numbers
  - File-Browser
  - - changed code so file-browser is always a standalone window
  - Project Interfaces Browser
  - - added actions to configure some IDL compiler options (-I, -D, -U)
  - Shell
  - - changed code so shell is always a standalone window
  - Translator
  - - added a translation engine for the IBM Watson Language Translator
  - Web Browser (NG)
  - - added default search engine definitions for
  * Qwant
  * StartPage
- Update to 18.07:
  - bug fixes
  - Checkers
  - - upgraded pyflakes to version 2.0.0
  - Debugger
  - - added support of breakpoint() builtin of Python 3.7
  - - added code to try to open the source file if an exception occurred in
    a cython .pyd file
  - Git Interface
  - - added capability to change the URL and/or user credentials for a
    remote repository
  - pip Interface
  - - added support for the '--user' option of install and list commands
  - - changed to use the new VirtualEnv Manager
  - Unit Test
  - - extended the standalone unit test tool to be able to open source in an
    editor window
  - VirtualEnv Manager
  - - added a manager for virtual environments
  - - changed a few places to use the newly introduced virtual environments
    (Note: a new session file format and debug properties file format
  has been introduced)
* Thu Jun  7 2018 hpj@urpla.net
- fix api requires/obsoletes
* Mon Jun  4 2018 hpj@urpla.net
- Update to 18.06:
  - bug fixes
  - Editor
  - - added a configuration option (Editor->Style page) to show the marker map
    on the left or right of the editor
  - - added a context menu for the "fold" margin
  - - improved handling of folded lines when using "go to" functions
  - - resize auto complete list box to fit with contents
  - - added a configuration option (Editor->autocomplete to set up maximum
    width and height of the auto complete list box
  - Shell
  - - resize auto complete list box to fit with contents
  - pip Interface
  - - added an action to install a locally available package/wheel
  - Web Browser (NG)
  - - improved the sending of the "Referer" header like it is done by Firefox
- remove eric-fix-bindir.patch: desktop files install fix is released from
  upstream
* Sun May 27 2018 hpj@urpla.net
- Use build conditionals to select qt version
- Further spec file cleanup
- Fix eric-api recommendation
* Thu May 24 2018 mcepl@suse.com
- Rename files from eric6 to eric, when applicable
- Build with Qt4 on LEAP 42.3
* Mon May 21 2018 hpj@urpla.net
- fix requires/obsoletes
- cleanup spec
* Fri May  4 2018 hpj@urpla.net
- use upstream fix for desktop files
* Tue May  1 2018 hpj@urpla.net
- Update to 18.05:
  - bug fixes
  - General
  - - added the '--disable-plugin=' option to disable plug-ins via the command
    line
  - Code Style Checker
  - - added support for '# noqa' and '# NOQA' comments to suppress warnings
  - - extended the dialog to be able to define the number of blank lines
    before class and function/method definitions
  - Project
  - - added support for 'make' to the Project menu and run it automatically
    before the main script is started (configuration option)
  - Syntax Checker
  - - added support for '# noqa' and '# NOQA' comments to suppress warnings
  - Translator
  - - updated the translator URL for DeepL
  - Web Browser (NG)
  - - improvement of the download manager
  - - added support for the Google Safe Browsing Lookup API (v4)
  - Third Party packages
  - - updated coverage.py to 4.5.1
  - - updated pycodestyle to 2.4.0
  - - updated send2trash to version 1.5.0
- Fix desktop files executable path
* Mon Apr 30 2018 hpj@urpla.net
- Update to 18.04:
  - bug fixes
  - General
  - - added config option to disable the use of the global menu bar on Linux
    Code Style Checker
  - - added checks for default docstring in functions and modules
  - - added check for dictionaries with sorted keys
  - - added checks for logging statements
  - - added check for the 'gettext' import statement
  - - added some checks of the bugbear checker
- Update to 18.03:
  - bug fixes
  - Editor
  - - added support for EditorConfig
  - - added VCS conflict markers to the types shown on the marker map
- Update to 18.02:
  - bug fixes
  - General
  - - extended the session to store/retrieve the split views and the order of
    the editors (Note: The new session file format is not backward compatible
    and cannot be read by eric releases prior to 18.02)
  - - added basic support for Cython
  - Editor
  - - added a context menu entry to "Execute Selection In Console"
  - Web Browser (NG)
  - - added support for HTML5 "Desktop Video Capture" and "Desktop Audio and
    Video Capture" as of Qt 5.10.0/PyQt 5.10.0
  - - added the capability to pause/resume download (Qt 5.10.0/PyQt 5.10.0)
  - - added support for attributes introduced by Qt 5.9 and Qt 5.10
- Rename package to eric6
* Sat Jan  6 2018 termim@gmail.com
- Update to 18.01:
  - bug fixes
  - Debugger / Breakpoint Viewer
  - - added the capability to remember the most recently used file names and
    conditions
  - Editor
  - - added an action to the view menu to clear all folds of the current editor
  - - added an entry to delete all change markers to the marker margin context
    menu
  - Project
  - - If a project does not contain protobuf files, the old project file format
    (5.1) is generated to make the file backward compatible.
  - Plug-ins
  - - added the pip interface plug-in to the core plug-ins
  - - added the virtualenv/pyvenv interface plug-in to the core plug-ins
  - - added the setup.py wizard plug-in to the core plug-ins
  - - added the eric plug-in wizard plug-in to the core plug-ins
  - - added the .desktop wizard plug-in to the core plug-ins
  - - added the translator plug-in to the core plug-ins
  - - added the git plug-in to the core plug-ins
  * *Note**: These plug-ins should be deinstalled via the plug-in
  uninstallation dialog of eric before upgrading eric. A reconfiguration of
  these plug-ins may be neccessary.
  - PluginToolPip
  - PluginWizardVirtualenv
* Thu Jan  4 2018 termim@gmail.com
- fix rpm build
* Tue Dec 26 2017 jengelh@inai.de
- Remove marketing from description.
* Fri Dec  8 2017 fabian@ritter-vogt.de
- Use PyQt5
- Drop python3-sip requires, python-qt5 already requires it
- Run spec-cleaner
- Use full URL for Source:
* Tue Dec  5 2017 termim@gmail.com
- Update to 17.12:
  - bug fixes
  - General
  - - added support for Google protobuf protocol files
  - Code Documentation Viewer
  - - added possibility to show the type of the object info is shown for
  - - modified the top row and the search part in order to allow smaller sizes
  - Debugger / Variables Viewer
  - - introduced a configuration option to limit the variables shown by the
    variables viewers depending on their size (in order to avoid overload
    situations on low power or low memory machines)
  - Styles
  - - added a dark style (*.qss and Python lexers) provided by Giuseppe
    Corbelli
  - Third Party packages
  - - updated send2trash to version 1.4.2
  * *NOTE**: This release introduces a new project file format that will be
    rejected by previous releases. The new format is needed for the Google
    protobuf support.
* Sun Nov 19 2017 termim@gmail.com
- Update to 17.11.1
  - Bug fixes
* Fri Nov  3 2017 termim@gmail.com
- Update to 17.11
  - Debugger:
  - added capability to enter an interpreter in the Start... dialog
  - Editor
  - added support for auto-completion lists being provided asynchronously
  - added a viewer for source code documentation extracted by providers
    to be implemented by plug-ins (like rope and jedi)
  - Web Browser (old style)
  - changed logic in order to put new downloads at the top of the list of
    downloads and added the download date and time to the shown info
  - Web Browser (NG)
  - changed logic in order to put new downloads at the top of the list of
    downloads and added the download date and time to the shown info
* Mon Oct  9 2017 termim@gmail.com
- Update to 17.10
  - bug fixes
  - Web Browser (NG)
  - added a downloader and installer/uninstaller dialog for spell check
    dictionaries
* Fri Sep  1 2017 termim@gmail.com
- Update to 17.09
  - bug fixes
  - Debugger
  - -  unified the Python2 and Python3 debugger interfaces
  - Exporter
  - - extended the HTML exporter to convert Markdown and ReST files to
    HTML
  - Plugin Manager
  - - added a bar with counts for new/local updates/remote updates to the
    plug-in repository dialog
  - Previewers
  - - added capability to configure the output format for the markdown
    and docutils (ReST) previewers
  - Web Browser (NG)
  - - added support for Google Safe Browsing
  - Third Party packages
  - - updated jasy to 1.5-beta5 (latest release available)
- remove i18 tarballs - they are already in the main archive.
* Fri Aug  4 2017 termim@gmail.com
- Update to 17.08
  - bug fixes
  - Shell
  - - added support for different history navigation styles (disabled,
    Linux, Windows)
  - - improved shell history dialog
  - Templates
  - added some new predefined template variables (time, path_name_rel,
    dir_name_rel)
  - Web Browser (NG)
  - - added support for sessions
* Sun Jul  2 2017 termim@gmail.com
- Update to 17.07
  - Background Services
  - - added functionality to limit the number of processes used for
    background services
  - Bug Reporting / Feature Request (Email)
  - - added the capability to send these emails via Google Mail using
    OAuth2 authentication
  - Diff Dialogs
  - -  made the colors of the diff dialogs configurable
  - Third Party packages
  - - updated chardet to 3.0.4
- Update to 17.06
  - bug fixes
  - Checkers
  - - extended the source documentation checker to check for raised/documented
    exceptions and defined/documented signals
  - Editor
  - - reintroduced the highlighting of current instruction line and the error
    line using colored background. It is configurable whether to use these
    backgrounds or the arrows.
  - - added capability to perform the various replace methods via keyboard
    shortcuts
  - Plugin Manager
  - - added an option to cleanup the plug-ins download area during startup
  - Qt Tools
  - - added code to auto-discover the presence of the new 'pyqt5-tools' wheel
    (Windows only) (thanks to Kyle Altendorf for providing this wheel)
  - Web Browser (NG)
  - - united the stop and reload buttons of the navigation bar
  - - added a super menu to modernize the look & feel
  - - added Ctrl-Click and middle click actions to the navigation buttons
    to perform the action in a new tab
* Sat May  6 2017 termim@gmail.com
- Update to 17.05
  - bug fixes
  - Editor
  - - changed the indication of the current instruction line and the error line
    to use a green or red arrow instead of a colored background
  - PyQt Tools
  - - added a configuration option for the path of the PyQt tools
  - Shell
  - - added a standalone shell window
  - Web Browser (NG)
  - - added the last visited time and date to the bookmark properties dialog
  - - added a visit count to the history entries (shown in the history dialog)
  - - made full screen mode really full screen
  - Third Party packages
  - - updated Pygments to 2.2.0
  - - updated chardet to 3.0.2
* Tue Apr 11 2017 termim@gmail.com
- Update to 17.04.1
  - - bug fixes
- Update to 17.04
  - bug fixes
  - General
  - - increased minimum required Python versions to prevent usage
    with very old versions (i.e. eric was never tested with)
    min. versions: Python 2 - 2.7.10; Python 3 - 3.4.0
  - Checkers
  - - added checks for shadowed Python builtins and unneccessary comprehensions
    and generators to the code style checker
  - - added a checker to check for lines of code of too high complexity
  - - added capability to place line flags (e.g. __IGNORE...) on the line
    following the one to be ignored
  - Debugger
  - - shell autocompleter takes the right global variables into account now
  - - move the instruction pointer within the current function (Hotkey: F12)
  - - report syntax and indentation errors raised by an application or module
    in the correct manner
  - - avoid crashes on using greenlets
  - Mercurial Interface
  - - extended the user configuration dialog
  - - added support for the 'zstd' compression for bundles (as of 4.1.0)
- add fetch script fetch-eric.sh
* Sat Mar 11 2017 termim@gmail.com
- Update to 17.03.1
  - bug fixes
* Fri Mar  3 2017 termim@gmail.com
- Update to 17.03
  - Checkers
  - - upgraded pycodestyle to version 2.3.1
  - - upgraded pyflakes to version 1.5.0
  - Debugger
  - - prevent stepping into print statements if checkbox for debugging into
    interpreter libraries is checked
  - - catch unhandled exceptions again
  - - support for PySide2 added
  - - atexit handling works as specified in any condition
  - - prevent ordinary breakpoints to steal the focus from an exception
  - Mercurial Interface
  - - improved the log browser in several ways
  - - improved the status dialog
  - Project
  - - added capability to remember previously used entries in the project
    debugger properties dialog
  - Web Browser (NG)
  - - added support for new options provided by Qt 5.8.0
  - - added support for spell checking as of Qt 5.8.0
* Sun Feb  5 2017 termim@gmail.com
- Update to 17.02.1
  - fixes a regression related to using eric with Qt 4.8.
- Update to 17.02
  - Checkers
  - - upgraded pycodestyle to version 2.2.0+
  - Debugger
  - - changed the variables filter dialog to be more user friendly
  - Editor
  - - added a bar with formatting options for HTML, Markdown and reStructured
    Text files
  - - added support for the new QScintilla JSON lexer
  - - added support for the new QScintilla Markdown lexer
  - Email
  - - added capability to use the SSL encryption method (next to StartTLS) in
    the built in Email dialog
  - Mercurial Interface
  - - added clickable links to the log browser details pane
  - - added up and down buttons to move the current entry to the log browser
  - - added the capability to configure the length of the log message shown
    in the message column of the log browser list
  - Subversion interface
  - - added up and down buttons to move the current entry to the log browser
  - Web Browser
  - - added functionality to manage the plug-in provided documentation sets
* Tue Jan  3 2017 termim@gmail.com
- Update to 17.01
  - bug fixes
  - General
  - - added capability to save a global session to disk and restore it
  - - added capability to save a crash session in order to restore the
    current state in case of a cras
  - - added option to configure the crash session startup behavior and
    added the '--no-crash' option to suppress looking for a crash session
  - - added the '--disable-crash' option to temporarily disable the crash
    session support through the command line
  - - changed some options: --noopen to --no-open, --nosplash to --no-splash
  - Debugger
  - - added capability to edit the history lists of the start dialogs of
    the debugger
  - Editor
  - - added support for project type specific auto-completion and
    calltips including the respective configuration (Editor->APIs page)
* Sat Dec  3 2016 termim@gmail.com
- Update to 16.12
  - Mercurial Interface
  - - added context menu actions to the tags/branches list dialog
  - - added bookmark actions to the Log Browser tools menu
  - - added context menu actions to the bookmark list dialog
  - - added possibility to enter a commit author and commit date/time
  - - added capability to enforce a tagging operation
  - Third Party packages
  - - updated chardet to 2.3.0
* Sun Nov 13 2016 termim@gmail.com
- Update to 16.11
  - bug fixes
  - General
  - - added a status bar icon to show the online status to the main window
  - - added an action to clear the private data of the IDE
  - Checkers
  - - added capaibility to ignore warnings by code (use
    __IGNORE_WARNING_<code>__, e.g. __IGNORE_WARNING_M613__)
  - Debugger
  - - added a debugger interface registry to allow debuggers being
    implemented as plug-ins
  - - Python Debuggers:
  - -- changed the protocol to a JSONRPC style protocol to be more robust
  - -- massive speed gain of the debug client (Tobias Rzepka)
  - -- unified the debugger clients for Python 2 and 3 (Tobias Rzepka)
  - -- unified the standard and threaded debugger clients (Tobias Rzepka)
  - -- added debug support for QThread threads (Tobias Rzepka)
  - - Ruby Debugger:
  - -- removed the Ruby debugger (the interface doesn't work with recent
    Ruby versions anymore)
  - - Call Trace Viewer
  - -- added capability to stop recording upon exit of the client script
  - - Variables Viewer
  - -- added capability to refresh the view via the context menu
  - Hex Editor
  - - added a nice little hex editor tool (usable as a standalone tool
    as well)
  - Icon Editor
  - - added capability to close all other icon editor windows
  - Project
  - - added a dialog to quickly search for files in the list of project files
    (thanks to Mike C. Fletcher for contributing the majority of this)
  - - added an option to rescan the project for tasks upon open
  - Project Browser
  - - added capability to search the file tree via the keyboard (directories and
    files only)
  - Tools
  - - Tray Starter
  - -- added an entry to show the version information
  - Version Control System Interfaces
  - - Mercurial
  - -- added support for pulling and pushing the current bookmark
  - -- added support for the strip extension
  - -- added support for the histedit extension
  - -- added support for the strip and fetch extensions to the log browser
  - -- added an action to the administration menu to clean out the backup
    bundles
  - Web Browser
  - - added capability to remember the zoom values for each site (incl. a
    dialog to manage these)
  - - added a status bar icon to show the online status
  - Web Browser (NG)
  - - ported the web browser to QtWebEngine as of Qt 5.6.0 because starting
    with this version QtWebKit is no longer (officially) supported
  - Third Party packages
  - - updated Pygments to 2.1.3
  - - updated pep8 to 2.1.0dev0 and renamed it to pycodestyle
  - - updated coverage.py to 4.1.0
  - - updated pyflakes to 1.2.3+
* Sun Nov  6 2016 termim@gmail.com
- Update to 6.1.11
  * bug fixes
* Sun Oct  9 2016 termim@gmail.com
- Update to 6.1.10
  * bug fixes
* Sun Sep  4 2016 termim@gmail.com
- Update to 6.1.9
  * bug fixes
* Sun Jul 31 2016 termim@gmail.com
- Update to 6.1.8
  * bug fixes
  * improves compatibility with PyQt5 5.7.0 and above
* Mon Jul  4 2016 termim@gmail.com
- Update to 6.1.7
  * bug fixes
* Sun Jun  5 2016 termim@gmail.com
- Update to 6.1.6
  * bug fixes
* Mon May  9 2016 termim@gmail.com
- Update to 6.1.5
  * bug fixes
  * improved Py2/3 compatibility thanks to Parsifal Herzog
* Wed Apr 13 2016 termim@gmail.com
- Update to 6.1.4
  * bug fixes
* Wed Mar  9 2016 termim@gmail.com
- Update to 6.1.3
  * bug fixes
* Mon Feb  8 2016 termim@gmail.com
- Update to 6.1.2
  * bug fixes
* Thu Jan  7 2016 termim@gmail.com
- Update to 6.1.1
  * bug fixes
* Sat Dec  5 2015 termim@gmail.com
- Update to 6.1.0
- General
  * added a configuration page to edit the list of mime types to
    be opened in an eric editor
  * added the '--settings=' command line switch to store the
    settings files in a non-standard directory
- Checkers
  * added a batch mode to the code style checker to make use of
    multiple CPUs/CPU-Cores
  * added a batch mode to the syntax checker to make use of
    multiple CPUs/CPU-Cores
  * added a batch mode to the indentation checker to make use of
    multiple CPUs/CPU-Cores
  * added a code complexity checker iaw. McCabe to the code style
    checker
  * added miscellaneous checks to the code style checker (coding
    comment, copyright, blind except, print statements, one element
    tuples, __future__ imports, old style string formats, string
    format strings)
- Debugger
  * added signal handlers for the Python debug clients
- Editor
  * added capability to configure the indentation guides colors
  * added capability to ask multiple completion list and call-tip
    providers
  * added support for mouse click handlers to be provided by plug-ins
  * added the search markers to the marker map
  * added capability to save a copy of the editor contents
  * Lexers
  - added support for the new C++ lexer properties (as of
    QScintilla V. 2.9.0)
- File Browser
  * added capability to show imports of a Python script
- Log Viewer
  * added a message filter including a configuration page
- Mini Editor
  * added capability to save a copy of the editor contents
- Preferences Dialog
  * changed the 'filter' function to a 'search' function disabling
    all entries, that don't contain the entered string
  * changed the handling of the configuration page list entries
    to be collapsed on first show and remember the expanded ones
    while eric is running (but not between invocations)
- Previewers
  * added capability to use 'Sphinx' to preview ReST files
- Project
  * added functionality to reorganize the files automatically,
    when the project type or file type associations are changed
- Project Browser
  * added capability to show imports of a Python script
- Source Code Documentor
  * added tags to describe the type of parameters (@type, @ptype)
    and return values (@rtype)
- Task Viewer
  * added capability to add sub-tasks (i.e. a task hierarchy) for
    manually generated tasks
- Tools
  * Diff Dialog
  - added capability to search in the output
- Version Control System Interfaces
  * All
  - added capability to search in the output of Diff dialogs
  * Mercurial
  - enhanced the log browser functionality by a search mode
  - enhanced the log browser functionality by pull and push actions
  - enhanced the status dialog functionality by a diff view
- Web Browser
  * added support for HTML5 feature permissions
  * improved parsing of the content disposition header analog to
    the way it is done in qutebrowser
  * modified and extended the VirusTotal interface for the v2 API
  * added our own web inspector window to overcome a Qt weekness
  * added a manager for Flash Cookies
- Third Party packages
  * updated coverage to 4.0
  * updated Pygments to 2.0.2
* Tue Nov 10 2015 termim@gmail.com
- Update to 6.0.11
  * bug fixes
* Wed Oct 21 2015 termim@gmail.com
- Update to 6.0.10
  * bug fixes
* Wed Sep  9 2015 termim@gmail.com
- Update to 6.0.9
  * bug fixes
* Fri Aug 14 2015 termim@gmail.com
- Update to 6.0.8
  * bug fixes
  * compatibility to PyQt 5.5
* Mon Jul  6 2015 termim@gmail.com
-  Update to 6.0.7
  * bug fixes
* Thu Jun 11 2015 termim@gmail.com
- Update to 6.0.6
  * bug fixes
* Tue May 12 2015 termim@gmail.com
- Update to 6.0.5
  * bug fixes
* Mon Apr 13 2015 termim@gmail.com
- Update to 6.0.4
  * bug fixes
* Mon Mar  2 2015 termim@gmail.com
-  Update to 6.0.3
  * bug fixes
* Fri Feb 20 2015 termim@gmail.com
- Update to 6.0.2
  * bug fixes
* Sun Jan 18 2015 termim@gmail.com
- Update to 6.0.1
  * bug fixes
* Mon Dec 29 2014 termim@gmail.com
- Initial checkin
